@@ -1,7 +1,7 @@
 """Declarative, dynamic option parsing."""
 
 # fmt: off
-__version__ = "3.0.0"
+__version__ = "3.1.0"
 __all__ = (
     # Options & arguments
     # -------------------
@@ -24,5 +24,5 @@ __all__ = (
 # fmt: on
 
 from lethargy.errors import ArgsError, MissingOption, OptionError, TransformError
-from lethargy.option import take_opt
+from lethargy.options import take_opt
 from lethargy.util import argv, expect, fail, show_errors
